@@ -114,6 +114,12 @@ sub matches {
     if ( $rule eq 'string' ) {
       _ok( $key, $item->{$key} );
     }
+    if ( $rule eq 'maybe_string' ) {
+      SKIP: {
+        Test::More::skip "$key is not defined", 1 unless defined $item->{$key} &&  length $item->{$key};
+        _ok( $key, $item->{$key} );
+      }
+    }
     if ( $rule eq 'integer' ) {
       _ok( $key, $item->{$key} );
     }
@@ -126,6 +132,13 @@ sub matches {
       _ok( $key, $item->{$key} );
       Test::More::ok ref $item->{$key} && $item->{$key}->isa('URI'), 'proper uri';
     }
+    if ( $rule eq 'maybe_uri' ) {
+      SKIP: {
+        Test::More::skip "$key is not defined", 2 unless defined $item->{$key} &&  length $item->{$key};
+        _ok( $key, $item->{$key} );
+        Test::More::ok ref $item->{$key} && $item->{$key}->isa('URI'), 'proper uri';
+      }
+    }
     if ( ref $rule eq 'HASH' ) {
       if ( ref $item->{$key} eq 'ARRAY' ) {
         foreach my $subitem ( @{ $item->{$key} } ) {
